Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(218)

Unified Diff: client/site_tests/power_LoadTest/power_LoadTest.py

Issue 2110005: Also stop powerd in power_Backlight and power_LoadTest (Closed) Base URL: ssh://git@chromiumos-git/autotest.git
Patch Set: Address review comments Created 10 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « client/site_tests/power_Backlight/power_Backlight.py ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: client/site_tests/power_LoadTest/power_LoadTest.py
diff --git a/client/site_tests/power_LoadTest/power_LoadTest.py b/client/site_tests/power_LoadTest/power_LoadTest.py
index 4f3ef72b8a99ff59a915c50c833a44e7093e00e0..a1e4d07f180e2697371e32c6ab4b48204b718089 100755
--- a/client/site_tests/power_LoadTest/power_LoadTest.py
+++ b/client/site_tests/power_LoadTest/power_LoadTest.py
@@ -88,8 +88,9 @@ class power_LoadTest(site_ui_test.UITest):
self._tmp_keyvals['level_backlight_current'] = int(
utils.system_output(cmd).rstrip())
# disable screen locker
os.system('stop screen-locker')
+ os.system('stop powerd')
# disable screen blanking. Stopping screen-locker isn't
# synchronous :(. Add a sleep for now, till powerd comes around
@@ -199,7 +200,8 @@ class power_LoadTest(site_ui_test.UITest):
def cleanup(self):
- # re-enable screen locker. This also re-enables dpms.
+ # re-enable screen locker and powerd. This also re-enables dpms.
+ os.system('start powerd')
os.system('start screen-locker')
« no previous file with comments | « client/site_tests/power_Backlight/power_Backlight.py ('k') | no next file » | no next file with comments »
@@ -88,8 +88,9 @@ class power_LoadTest(site_ui_test.UITest):
self._tmp_keyvals['level_backlight_current'] = int(
utils.system_output(cmd).rstrip())
- # disable screen locker
+ # disable screen locker and powerd
os.system('stop screen-locker')

Powered by Google App Engine
This is Rietveld 408576698